@@ -1,5 +1,5 @@
 package Dir::Manifest::Key;
-$Dir::Manifest::Key::VERSION = '0.2.0';
+$Dir::Manifest::Key::VERSION = '0.4.0';
 use strict;
 use warnings;
 use 5.014;
@@ -19,13 +19,9 @@ __END__
 
 =encoding UTF-8
 
-=head1 NAME
-
-Dir::Manifest::Key
-
 =head1 VERSION
 
-version 0.2.0
+version 0.4.0
 
 =head1 DESCRIPTION
 
@@ -41,10 +37,6 @@ be done securely and reliably.
 
 Dir::Manifest::Key - a Dir::Manifest key.
 
-=head1 VERSION
-
-version 0.2.0
-
 =head1 METHODS
 
 =head2 $self->key()
@@ -55,7 +47,7 @@ The key as string.
 
 A L<Path::Tiny> object for reading from the file.
 
-=for :stopwords cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
+=for :stopwords cpan testmatrix url bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
 
 =head1 SUPPORT
 
@@ -92,14 +84,6 @@ L<https://rt.cpan.org/Public/Dist/Display.html?Name=Dir-Manifest>
 
 =item *
 
-AnnoCPAN
-
-The AnnoCPAN is a website that allows community annotations of Perl module documentation.
-
-L<http://annocpan.org/dist/Dir-Manifest>
-
-=item *
-
 CPAN Ratings
 
 The CPAN Ratings is a website that allows community ratings and reviews of Perl modules.
