@@ -1,5 +1,5 @@
 package Dir::Manifest::Slurp;
-$Dir::Manifest::Slurp::VERSION = '0.2.0';
+$Dir::Manifest::Slurp::VERSION = '0.4.0';
 use strict;
 use warnings;
 
@@ -40,22 +40,14 @@ __END__
 
 =encoding UTF-8
 
-=head1 NAME
-
-Dir::Manifest::Slurp
-
 =head1 VERSION
 
-version 0.2.0
+version 0.4.0
 
 =head1 NAME
 
 Dir::Manifest::Slurp - utility functions for slurping .
 
-=head1 VERSION
-
-version 0.2.0
-
 =head1 EXPORTS
 
 =head2 my $new_string = as_lf($string)
@@ -75,7 +67,7 @@ UTF-8 after using as_lf .
 
 UTF-8
 
-=for :stopwords cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
+=for :stopwords cpan testmatrix url bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
 
 =head1 SUPPORT
 
@@ -112,14 +104,6 @@ L<https://rt.cpan.org/Public/Dist/Display.html?Name=Dir-Manifest>
 
 =item *
 
-AnnoCPAN
-
-The AnnoCPAN is a website that allows community annotations of Perl module documentation.
-
-L<http://annocpan.org/dist/Dir-Manifest>
-
-=item *
-
 CPAN Ratings
 
 The CPAN Ratings is a website that allows community ratings and reviews of Perl modules.
